yakumo.neutron.v2.subnet

Package yakumo :: Package neutron :: Package v2 :: Module subnet |
[hide private]
[frames] | no frames]

# Module subnet

source code

Resource class and its manager for subnets in Networking V2 API

Classes | [hide private]
| Resource Resource class for subnets in Networking V2 API
| Manager Manager class for subnets in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('network',
       'network_id', mapper.Resource('neutron.network')), ('gateway_ip', 'ga
      teway_ip', mapper.Noop), ('dns_nameservers', 'dns_nameservers', mapper
      .Noop), ('host_route', 'host_route', mapper.Noop), ('ip_version', 'ip_
      version', mapper.Noop), ('cidr', 'cidr', mapper.Noop), ('is_dhcp_enabl
      ed', 'enable_dhcp', mapper.Noop), ('ipv6_ra_mode', 'ipv6_ra_mode', map
      per.Noop), ('ipv6_address_mode', 'ipv6_address_mode', mapper.Noop),]